@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.7
+#!/usr/bin/env python
 """
 oledir.py
 
@@ -14,7 +14,7 @@ http://www.decalage.info/python/oletools
 
 #=== LICENSE ==================================================================
 
-# oledir is copyright (c) 2015-2018 Philippe Lagadec (http://www.decalage.info)
+# oledir is copyright (c) 2015-2019 Philippe Lagadec (http://www.decalage.info)
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without modification,
@@ -50,8 +50,10 @@ from __future__ import print_function
 #                      - added support for zip files and wildcards
 # 2018-04-11 v0.53 PL: - added table displaying storage tree and CLSIDs
 # 2018-04-13       PL: - moved KNOWN_CLSIDS to common.clsid
+# 2018-08-28 v0.54 PL: - olefile is now a dependency
+# 2018-10-06           - colorclass is now a dependency
 
-__version__ = '0.53'
+__version__ = '0.54'
 
 #------------------------------------------------------------------------------
 # TODO:
@@ -62,6 +64,13 @@ __version__ = '0.53'
 
 import sys, os, optparse
 
+import olefile
+import colorclass
+
+# On Windows, colorclass needs to be enabled:
+if os.name == 'nt':
+    colorclass.Windows.enable(auto_colors=True)
+
 # IMPORTANT: it should be possible to run oletools directly as scripts
 # in any directory without installing them with pip or setup.py.
 # In that case, relative imports are NOT usable.
@@ -74,20 +83,6 @@ _parent_dir = os.path.normpath(os.path.join(_thismodule_dir, '..'))
 if not _parent_dir in sys.path:
     sys.path.insert(0, _parent_dir)
 
-# we also need the thirdparty dir for colorclass
-# TODO: remove colorclass from thirdparty, make it a dependency
-_thirdparty_dir = os.path.normpath(os.path.join(_thismodule_dir, 'thirdparty'))
-# print('_thirdparty_dir = %r' % _thirdparty_dir)
-if not _thirdparty_dir in sys.path:
-    sys.path.insert(0, _thirdparty_dir)
-
-import colorclass
-
-# On Windows, colorclass needs to be enabled:
-if os.name == 'nt':
-    colorclass.Windows.enable(auto_colors=True)
-
-from oletools.thirdparty import olefile
 from oletools.thirdparty.tablestream import tablestream
 from oletools.thirdparty.xglob import xglob
 from oletools.common.clsid import KNOWN_CLSIDS
@@ -130,8 +125,9 @@ def sid_display(sid):
         return sid
 
 def clsid_display(clsid):
-    if clsid in KNOWN_CLSIDS:
-        clsid += '\n%s' % KNOWN_CLSIDS[clsid]
+    clsid_upper = clsid.upper()
+    if clsid_upper in KNOWN_CLSIDS:
+        clsid += '\n%s' % KNOWN_CLSIDS[clsid_upper]
     color = 'yellow'
     if 'CVE' in clsid:
         color = 'red'
